Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(738)

Unified Diff: chrome/browser/ui/views/payments/payment_request_dialog.h

Issue 2611253004: [Payment Request] Change the lifetime management of PaymentRequestImpl (Closed)
Patch Set: PaymentRequestImpl -> PaymentRequest Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/payment_request_dialog.h
diff --git a/chrome/browser/ui/views/payments/payment_request_dialog.h b/chrome/browser/ui/views/payments/payment_request_dialog.h
index d9e0474dcfe1a00a42b559d38e8c76fe0b8705f5..1ab4a73796f16fc79c50aeac904e0ea84fe34209 100644
--- a/chrome/browser/ui/views/payments/payment_request_dialog.h
+++ b/chrome/browser/ui/views/payments/payment_request_dialog.h
@@ -14,7 +14,7 @@
namespace payments {
-class PaymentRequestImpl;
+class PaymentRequest;
class PaymentRequestSheetController;
// Maps views owned by PaymentRequestDialog::view_stack_ to their controller.
@@ -28,7 +28,7 @@ using ControllerMap =
// the WebPayments flow and managing the transition between those states.
class PaymentRequestDialog : public views::DialogDelegateView {
public:
- explicit PaymentRequestDialog(PaymentRequestImpl* impl);
+ explicit PaymentRequestDialog(PaymentRequest* request);
~PaymentRequestDialog() override;
// views::WidgetDelegate
@@ -51,11 +51,11 @@ class PaymentRequestDialog : public views::DialogDelegateView {
void ViewHierarchyChanged(const ViewHierarchyChangedDetails& details)
override;
- // Non-owned reference to the PaymentRequestImpl that initiated this dialog.
- // Since the PaymentRequestImpl object always outlives this one, the pointer
- // should always be valid even though there is no direct ownership
- // relationship between the two.
- PaymentRequestImpl* impl_;
+ // Non-owned reference to the PaymentRequest that initiated this dialog. Since
+ // the PaymentRequest object always outlives this one, the pointer should
+ // always be valid even though there is no direct ownership relationship
+ // between the two.
+ PaymentRequest* request_;
ControllerMap controller_map_;
ViewStack view_stack_;

Powered by Google App Engine
This is Rietveld 408576698